@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2016-2020 Canonical, Ltd.
+ * Copyright (C) 2016-2021 Canonical, Ltd.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -293,8 +293,8 @@ static inline int pagein_all_procs(
 
 int main(int argc, char **argv)
 {
-	int64_t memfree_begin, memfree_end;
-	int64_t swapfree_begin, swapfree_end;
+	int64_t memfree_begin = 0, memfree_end = 0;
+	int64_t swapfree_begin = 0, swapfree_end = 0;
 	int64_t delta;
 	int64_t total_pages_touched = 0ULL;
 	int64_t total_pages_skipped = 0ULL;
